==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/nl.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Eerste start wizard",
    "Add your profile information! For example your email is needed to reset your password." : "Voeg je profielinformatie toe! Je email-adres is bijvoorbeeld nodig om je wachtwoord te herstellen.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Voeg profielinformatie toe! Stel een profielfoto in en voer je volledige naam in voor makkelijker herkenning over alle functies.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Voeg profielinformatie toe! Voer je volledige naam in voor makkelijker herkenning over alle functies.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Voeg profielinformatie toe! Stel een profielfoto in voor makkelijker herkenning over alle functies.",
    "Get the apps to sync your files" : "Download de apps om bestanden te synchen",
    "Desktop client" : "Desktop client",
    "Android app" : "Android app",
    "iOS app" : "iOS app",
    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "Als je het project wilt ondersteunen {contributeopen}help met de ontwikkeling{linkclose} of {contributeopen}zegt het voort{linkclose}!",
    "Show First Run Wizard again" : "Toon de eerste start wizard opnieuw",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "Gebruik & deel je bestanden, agenda's, contactpersonen, e-mail & meer, vanaf elk apparaat, op je eigen voorwaarden",
    "Connect your desktop apps to %s" : "Verbind je desktop apps met %s",
    "Connect your calendar" : "Verbind je agenda",
    "Connect your contacts" : "Verbind je contactpersonen",
    "Access files via WebDAV" : "Benader bestanden via WebDAV",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>." : "Er staat meer informatie in de <a target=\"_blank\" href=\"%s\">documentatie</a> en op onze <a target=\"_blank\" href=\"%s\">website</a>.",
    "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!" : "Als je Nextcloud leuk vindt, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is een fantastisch open software product om je bestanden te synchroniseren en te delen. Je kunt het gratis verkrijgen op https://nextcloud.com\">, beveel het aan bij je vrienden</a> en <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">lever een bijdrage</a>!",
    "Connect your Calendar" : "Verbind je agenda",
    "Connect your Contacts" : "Verbind je contactpersonen"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/nl.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Eerste start wizard",
    "Add your profile information! For example your email is needed to reset your password." : "Voeg je profielinformatie toe! Je email-adres is bijvoorbeeld nodig om je wachtwoord te herstellen.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Voeg profielinformatie toe! Stel een profielfoto in en voer je volledige naam in voor makkelijker herkenning over alle functies.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Voeg profielinformatie toe! Voer je volledige naam in voor makkelijker herkenning over alle functies.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Voeg profielinformatie toe! Stel een profielfoto in voor makkelijker herkenning over alle functies.",
    "Get the apps to sync your files" : "Download de apps om bestanden te synchen",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "%s geeft je toegang tot je bestanden, waar je ook maar bent. Onze makkelijk te gebruiken desktop en mobiele applicaties zijn voor ieder groot platform gratis beschikbaar.",
    "Desktop client" : "Desktop client",
    "Android app" : "Android app",
    "iOS app" : "iOS app",
    "Setup sync clients using an <a href=\"\">app password</a>. That way you can make sure you are able to revoke access in case you loose that device." : "Installeer Sync clients met een <a href=\"\">app wachtwoord</a>. Dan kan je toegang intrekken zodra je je apparaat verliest.",
    "Connect other apps to %s" : "Verbind andere apps met 1%s",
    "Connect your calendar" : "Verbind je agenda",
    "Connect your contacts" : "Verbind je contactpersonen",
    "Access files via WebDAV" : "Benader bestanden via WebDAV",
    "The first run wizard helps you to get started with %s." : "De wizard helpt je op weg met 1%s.",
    "Show first run wizard again" : "Toon de Eerste start Wizard opnieuw",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "Gebruik & deel je bestanden, agenda's, contactpersonen, e-mail & meer, vanaf elk apparaat, op je eigen voorwaarden",
    "Connect your desktop apps to %s" : "Verbind je desktop apps met %s",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>." : "Er staat meer informatie in de <a target=\"_blank\" href=\"%s\">documentatie</a> en op onze <a target=\"_blank\" href=\"%s\">website</a>.",
    "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!" : "Als je Nextcloud leuk vindt, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is een fantastisch open software product om je bestanden te synchroniseren en te delen. Je kunt het gratis verkrijgen op https://nextcloud.com\">, beveel het aan bij je vrienden</a> en <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">lever een bijdrage</a>!",
    "Connect your Calendar" : "Verbind je agenda",
    "Connect your Contacts" : "Verbind je contactpersonen",
    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "Als je het project wilt ondersteunen {contributeopen}help met de ontwikkeling{linkclose} of {contributeopen}zegt het voort{linkclose}!",
    "Show First Run Wizard again" : "Toon de eerste start wizard opnieuw"
},
"nplurals=2; plural=(n != 1);");
